$(document).ready(function() {
	// 可能会有多个音频，逐个初始化音频控制事件
	initAudioEvent();
});

function initAudioEvent() {
	var audio = $(".audio_element")[0];
	$(".audio_element").on("loadedmetadata", function() {
		$(this).data("duration", this.duration);
		$(".duration").text(transTime(this.duration))
	});

	// 监听音频播放时间并更新进度条
	$(".audio_element").on("timeupdate", function() {
		updateProgress(this);
	});

	// 监听播放完成事件
	$(".audio_element").on("ended", function() {
		audioEnded(audio);
	});
	// 点击播放/暂停图片时，控制音乐的播放与暂停
	
	$(".play_element").on("touchend",function(e) {
		e.stopPropagation();
		if(audio.paused) {
			// 开始播放当前点击的音频
			audio.play();
			$(this).attr('src', 'https://appdownload.investassistant.com/resources/accountV3/img/pause_img.png');
		} else {
			audio.pause();
			$(this).attr('src', 'https://appdownload.investassistant.com/resources/accountV3/img/play_img.png');
		}
		
	});

    //点击进度条
    $('.progress_bg').on('mousedown', function(e) {
        e.stopPropagation();
        console.log(audio.currentTime)
        // 只有音乐开始播放后才可以调节，已经播放过但暂停了的也可以
        if(!audio.paused || audio.currentTime != 0) {
            var pgsWidth = $(this).width();
            var rate = e.offsetX / pgsWidth;
            audio.currentTime = audio.duration * rate;
            updateProgress(audio);
        }
    });

    dragProgressDotEvent(audio);

}

/**
 * 更新进度条与当前播放时间
 * @param {object} audio - audio对象
 */
function updateProgress(audio) {
	var user = navigator.userAgent.toLocaleLowerCase();
	if(user.indexOf("iphone") >= 0 || user.indexOf("ipad") >= 0) {
		
		var value = audio.currentTime / $(audio).data("duration");
	} else {
		var value = audio.currentTime / audio.duration;
	}
	console.log(value)
	$('.progress_audio').css('width', value * 100 + '%');
    $(".play_element").css("left",value * 5.8+"rem");
//	$(audio).parent().next().html(transTime(audio.currentTime));
}

/**
 * 播放完成时把进度调回开始的位置
 */
function audioEnded(audio) {
	$('.progress_audio').css('width', 0);
	// $('.play_element').attr('src', 'https://appdownload.investassistant.com/resources/accountV3/img/pause_img.png');
    $(".play_element").attr('src', 'https://appdownload.investassistant.com/resources/accountV3/img/play_img.png').css("left",0);
    audio.currentTime = 0;
}

/**
 * 音频播放时间换算
 * @param {number} value - 音频当前播放时间，单位秒
 */
function transTime(value) {
	var time = "";
	var h = parseInt(value / 3600);
	value %= 3600;
	var m = parseInt(value / 60);
	var s = parseInt(value % 60);
	if(h > 0) {
		time = formatTime(h + ":" + m + ":" + s);
	} else {
		time = formatTime(m + ":" + s);
	}

	return time;
}

/**
 * 格式化时间显示，补零对齐
 * eg：2:4  -->  02:04
 * @param {string} value - 形如 h:m:s 的字符串 
 */
function formatTime(value) {
	var time = "";
	var s = value.split(':');
	var i = 0;
	for(; i < s.length - 1; i++) {
		time += s[i].length == 1 ? ("0" + s[i]) : s[i];
		time += ":";
	}
	time += s[i].length == 1 ? ("0" + s[i]) : s[i];

	return time;
}

function dragProgressDotEvent(audio) {
    var dot = $(".play_element")[0]

    var position = {
        oriOffestLeft: 0, // 移动开始时进度条的点距离进度条的偏移值
        oriX: 0, // 移动开始时的x坐标
        maxLeft: 0, // 向左最大可拖动距离
        maxRight: 0 // 向右最大可拖动距离
    };
    var flag = false; // 标记是否拖动开始

    // 鼠标按下时
    dot.addEventListener('mousedown', down, false);
    dot.addEventListener('touchstart', down, false);

    // 开始拖动
    document.addEventListener('mousemove', move, false);
    document.addEventListener('touchmove', move, false);

    // 拖动结束
    document.addEventListener('mouseup', end, false);
    document.addEventListener('touchend', end, false);

    function down(event) {
        if (!audio.paused || audio.currentTime != 0) { // 只有音乐开始播放后才可以调节，已经播放过但暂停了的也可以
            flag = true;

            position.oriOffestLeft = dot.offsetLeft;
            position.oriX = event.touches ? event.touches[0].clientX : event.clientX; // 要同时适配mousedown和touchstart事件
            position.maxLeft = position.oriOffestLeft; // 向左最大可拖动距离
            position.maxRight = $('.progress_bg')[0].offsetWidth - position.oriOffestLeft; // 向右最大可拖动距离

            // 禁止默认事件（避免鼠标拖拽进度点的时候选中文字）
            if (event && event.preventDefault) {
                event.preventDefault();
            } else {
                event.returnValue = false;
            }

            // 禁止事件冒泡
            if (event && event.stopPropagation) {
                event.stopPropagation();
            } else {
                window.event.cancelBubble = true;
            }
        }
    }

    function move(event) {
        if (flag) {
            var clientX = event.touches ? event.touches[0].clientX : event.clientX; // 要同时适配mousemove和touchmove事件
            var length = clientX - position.oriX;
            if (length > position.maxRight) {
                length = position.maxRight;
            } else if (length < -position.maxLeft) {
                length = -position.maxLeft;
            }
            var pgsWidth = $('.progress_bg').width();
            var rate = (position.oriOffestLeft + length) / pgsWidth;
            audio.currentTime = audio.duration * rate;
            updateProgress(audio);
        }
    }

    function end() {
        flag = false;
        //audio.play();
    }
}